@@ -5,29 +5,86 @@ The main entry point to these classes should be through
 :meth:`can.BusABC.send_periodic`.
 """
 
-from typing import Optional, Sequence, Tuple, Union, Callable, TYPE_CHECKING
+import abc
+import logging
+import platform
+import sys
+import threading
+import time
+import warnings
+from typing import (
+    TYPE_CHECKING,
+    Callable,
+    Final,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+    cast,
+)
 
 from can import typechecking
+from can.message import Message
 
 if TYPE_CHECKING:
     from can.bus import BusABC
 
-from can.message import Message
-
-import abc
-import logging
-import threading
-import time
-
-# try to import win32event for event-based cyclic send task (needs the pywin32 package)
-try:
-    import win32event
-
-    HAS_EVENTS = True
-except ImportError:
-    HAS_EVENTS = False
 
 log = logging.getLogger("can.bcm")
+NANOSECONDS_IN_SECOND: Final[int] = 1_000_000_000
+
+
+class _Pywin32Event:
+    handle: int
+
+
+class _Pywin32:
+    def __init__(self) -> None:
+        import pywintypes  # pylint: disable=import-outside-toplevel,import-error
+        import win32event  # pylint: disable=import-outside-toplevel,import-error
+
+        self.pywintypes = pywintypes
+        self.win32event = win32event
+
+    def create_timer(self) -> _Pywin32Event:
+        try:
+            event = self.win32event.CreateWaitableTimerEx(
+                None,
+                None,
+                self.win32event.CREATE_WAITABLE_TIMER_HIGH_RESOLUTION,
+                self.win32event.TIMER_ALL_ACCESS,
+            )
+        except (
+            AttributeError,
+            OSError,
+            self.pywintypes.error,  # pylint: disable=no-member
+        ):
+            event = self.win32event.CreateWaitableTimer(None, False, None)
+
+        return cast(_Pywin32Event, event)
+
+    def set_timer(self, event: _Pywin32Event, period_ms: int) -> None:
+        self.win32event.SetWaitableTimer(event.handle, 0, period_ms, None, None, False)
+
+    def stop_timer(self, event: _Pywin32Event) -> None:
+        self.win32event.SetWaitableTimer(event.handle, 0, 0, None, None, False)
+
+    def wait_0(self, event: _Pywin32Event) -> None:
+        self.win32event.WaitForSingleObject(event.handle, 0)
+
+    def wait_inf(self, event: _Pywin32Event) -> None:
+        self.win32event.WaitForSingleObject(
+            event.handle,
+            self.win32event.INFINITE,
+        )
+
+
+PYWIN32: Optional[_Pywin32] = None
+if sys.platform == "win32" and sys.version_info < (3, 11):
+    try:
+        PYWIN32 = _Pywin32()
+    except ImportError:
+        pass
 
 
 class CyclicTask(abc.ABC):
@@ -44,7 +101,7 @@ class CyclicTask(abc.ABC):
         """
 
 
-class CyclicSendTaskABC(CyclicTask):
+class CyclicSendTaskABC(CyclicTask, abc.ABC):
     """
     Message send task with defined period
     """
@@ -64,6 +121,7 @@ class CyclicSendTaskABC(CyclicTask):
         # Take the Arbitration ID of the first element
         self.arbitration_id = messages[0].arbitration_id
         self.period = period
+        self.period_ns = int(round(period * 1e9))
         self.messages = messages
 
     @staticmethod
@@ -104,7 +162,7 @@ class CyclicSendTaskABC(CyclicTask):
         return messages
 
 
-class LimitedDurationCyclicSendTaskABC(CyclicSendTaskABC):
+class LimitedDurationCyclicSendTaskABC(CyclicSendTaskABC, abc.ABC):
     def __init__(
         self,
         messages: Union[Sequence[Message], Message],
@@ -124,9 +182,10 @@ class LimitedDurationCyclicSendTaskABC(CyclicSendTaskABC):
         """
         super().__init__(messages, period)
         self.duration = duration
+        self.end_time: Optional[float] = None
 
 
-class RestartableCyclicTaskABC(CyclicSendTaskABC):
+class RestartableCyclicTaskABC(CyclicSendTaskABC, abc.ABC):
     """Adds support for restarting a stopped cyclic task"""
 
     @abc.abstractmethod
@@ -134,9 +193,7 @@ class RestartableCyclicTaskABC(CyclicSendTaskABC):
         """Restart a stopped periodic task."""
 
 
-class ModifiableCyclicTaskABC(CyclicSendTaskABC):
-    """Adds support for modifying a periodic message"""
-
+class ModifiableCyclicTaskABC(CyclicSendTaskABC, abc.ABC):
     def _check_modified_messages(self, messages: Tuple[Message, ...]) -> None:
         """Helper function to perform error checking when modifying the data in
         the cyclic task.
@@ -180,7 +237,7 @@ class ModifiableCyclicTaskABC(CyclicSendTaskABC):
         self.messages = messages
 
 
-class MultiRateCyclicSendTaskABC(CyclicSendTaskABC):
+class MultiRateCyclicSendTaskABC(CyclicSendTaskABC, abc.ABC):
     """A Cyclic send task that supports switches send frequency after a set time."""
 
     def __init__(
@@ -208,7 +265,7 @@ class MultiRateCyclicSendTaskABC(CyclicSendTaskABC):
 
 
 class ThreadBasedCyclicSendTask(
-    ModifiableCyclicTaskABC, LimitedDurationCyclicSendTaskABC, RestartableCyclicTaskABC
+    LimitedDurationCyclicSendTaskABC, ModifiableCyclicTaskABC, RestartableCyclicTaskABC
 ):
     """Fallback cyclic send task using daemon thread."""
 
@@ -220,6 +277,8 @@ class ThreadBasedCyclicSendTask(
         period: float,
         duration: Optional[float] = None,
         on_error: Optional[Callable[[Exception], bool]] = None,
+        autostart: bool = True,
+        modifier_callback: Optional[Callable[[Message], None]] = None,
     ) -> None:
         """Transmits `messages` with a `period` seconds for `duration` seconds on a `bus`.
 
@@ -241,21 +300,37 @@ class ThreadBasedCyclicSendTask(
         self.send_lock = lock
         self.stopped = True
         self.thread: Optional[threading.Thread] = None
-        self.end_time: Optional[float] = (
-            time.perf_counter() + duration if duration else None
-        )
         self.on_error = on_error
+        self.modifier_callback = modifier_callback
 
-        if HAS_EVENTS:
-            self.period_ms = int(round(period * 1000, 0))
-            self.event = win32event.CreateWaitableTimer(None, False, None)
+        self.period_ms = int(round(period * 1000, 0))
 
-        self.start()
+        self.event: Optional[_Pywin32Event] = None
+        if PYWIN32:
+            if self.period_ms == 0:
+                # A period of 0 would mean that the timer is signaled only once
+                raise ValueError("The period cannot be smaller than 0.001 (1 ms)")
+            self.event = PYWIN32.create_timer()
+        elif (
+            sys.platform == "win32"
+            and sys.version_info < (3, 11)
+            and platform.python_implementation() == "CPython"
+        ):
+            warnings.warn(
+                f"{self.__class__.__name__} may achieve better timing accuracy "
+                f"if the 'pywin32' package is installed.",
+                RuntimeWarning,
+                stacklevel=1,
+            )
+
+        if autostart:
+            self.start()
 
     def stop(self) -> None:
-        if HAS_EVENTS:
-            win32event.CancelWaitableTimer(self.event.handle)
         self.stopped = True
+        if self.event and PYWIN32:
+            # Reset and signal any pending wait by setting the timer to 0
+            PYWIN32.stop_timer(self.event)
 
     def start(self) -> None:
         self.stopped = False
@@ -264,35 +339,56 @@ class ThreadBasedCyclicSendTask(
             self.thread = threading.Thread(target=self._run, name=name)
             self.thread.daemon = True
 
-            if HAS_EVENTS:
-                win32event.SetWaitableTimer(
-                    self.event.handle, 0, self.period_ms, None, None, False
-                )
+            self.end_time: Optional[float] = (
+                time.perf_counter() + self.duration if self.duration else None
+            )
+
+            if self.event and PYWIN32:
+                PYWIN32.set_timer(self.event, self.period_ms)
 
             self.thread.start()
 
     def _run(self) -> None:
         msg_index = 0
+        msg_due_time_ns = time.perf_counter_ns()
+
+        if self.event and PYWIN32:
+            # Make sure the timer is non-signaled before entering the loop
+            PYWIN32.wait_0(self.event)
+
         while not self.stopped:
-            # Prevent calling bus.send from multiple threads
-            with self.send_lock:
-                started = time.perf_counter()
-                try:
-                    self.bus.send(self.messages[msg_index])
-                except Exception as exc:  # pylint: disable=broad-except
-                    log.exception(exc)
-                    if self.on_error:
-                        if not self.on_error(exc):
-                            break
-                    else:
-                        break
             if self.end_time is not None and time.perf_counter() >= self.end_time:
+                self.stop()
                 break
+
+            try:
+                if self.modifier_callback is not None:
+                    self.modifier_callback(self.messages[msg_index])
+                with self.send_lock:
+                    # Prevent calling bus.send from multiple threads
+                    self.bus.send(self.messages[msg_index])
+            except Exception as exc:  # pylint: disable=broad-except
+                log.exception(exc)
+
+                # stop if `on_error` callback was not given
+                if self.on_error is None:
+                    self.stop()
+                    raise exc
+
+                # stop if `on_error` returns False
+                if not self.on_error(exc):
+                    self.stop()
+                    break
+
+            if not self.event:
+                msg_due_time_ns += self.period_ns
+
             msg_index = (msg_index + 1) % len(self.messages)
 
-            if HAS_EVENTS:
-                win32event.WaitForSingleObject(self.event.handle, self.period_ms)
+            if self.event and PYWIN32:
+                PYWIN32.wait_inf(self.event)
             else:
                 # Compensate for the time it takes to send the message
-                delay = self.period - (time.perf_counter() - started)
-                time.sleep(max(0.0, delay))
+                delay_ns = msg_due_time_ns - time.perf_counter_ns()
+                if delay_ns > 0:
+                    time.sleep(delay_ns / NANOSECONDS_IN_SECOND)
