@@ -1,4 +1,3 @@
-import ctypes
 import time
 from typing import Dict, List, Optional, Tuple
 
@@ -17,9 +16,10 @@ class EtasBus(can.BusABC):
         bitrate: int = 1000000,
         fd: bool = True,
         data_bitrate: int = 2000000,
-        **kwargs: object,
+        **kwargs: Dict[str, any],
     ):
         self.receive_own_messages = receive_own_messages
+        self._can_protocol = can.CanProtocol.CAN_FD if fd else can.CanProtocol.CAN_20
 
         nodeRange = CSI_NodeRange(CSI_NODE_MIN, CSI_NODE_MAX)
         self.tree = ctypes.POINTER(CSI_Tree)()
@@ -117,6 +117,9 @@ class EtasBus(can.BusABC):
 
         self.channel_info = channel
 
+        # Super call must be after child init since super calls set_filters
+        super().__init__(channel=channel, **kwargs)
+
     def _recv_internal(
         self, timeout: Optional[float]
     ) -> Tuple[Optional[can.Message], bool]:
@@ -226,10 +229,10 @@ class EtasBus(can.BusABC):
 
         self._oci_filters = (ctypes.POINTER(OCI_CANRxFilterEx) * len(filters))()
 
-        for i, filter in enumerate(filters):
+        for i, filter_ in enumerate(filters):
             f = OCI_CANRxFilterEx()
-            f.frameIDValue = filter["can_id"]
-            f.frameIDMask = filter["can_mask"]
+            f.frameIDValue = filter_["can_id"]
+            f.frameIDMask = filter_["can_mask"]
             f.tag = 0
             f.flagsValue = 0
             if self.receive_own_messages:
@@ -238,7 +241,7 @@ class EtasBus(can.BusABC):
             else:
                 # enable the SR bit in the mask. since the bit is 0 in flagsValue -> do not self-receive
                 f.flagsMask = OCI_CAN_MSG_FLAG_SELFRECEPTION
-            if filter.get("extended"):
+            if filter_.get("extended"):
                 f.flagsValue |= OCI_CAN_MSG_FLAG_EXTENDED
                 f.flagsMask |= OCI_CAN_MSG_FLAG_EXTENDED
             self._oci_filters[i].contents = f
@@ -297,7 +300,7 @@ class EtasBus(can.BusABC):
         tree = ctypes.POINTER(CSI_Tree)()
         CSI_CreateProtocolTree(ctypes.c_char_p(b""), nodeRange, ctypes.byref(tree))
 
-        nodes: Dict[str, str] = []
+        nodes: List[Dict[str, str]] = []
 
         def _findNodes(tree, prefix):
             uri = f"{prefix}/{tree.contents.item.uriName.decode()}"
