@@ -13,16 +13,22 @@ import ctypes
 import functools
 import logging
 import sys
-from typing import Optional, Callable, Tuple
+import warnings
+from typing import Callable, List, Optional, Sequence, Tuple, Union
 
-from can import BusABC, Message
-from can.bus import BusState
-from can.exceptions import CanInterfaceNotImplementedError, CanInitializationError
-from can.broadcastmanager import (
+from can import (
+    BusABC,
+    BusState,
+    CanProtocol,
+    CyclicSendTaskABC,
     LimitedDurationCyclicSendTaskABC,
+    Message,
     RestartableCyclicTaskABC,
 )
-from can.ctypesutil import CLibrary, HANDLE, PHANDLE, HRESULT as ctypes_HRESULT
+from can.ctypesutil import HANDLE, PHANDLE, CLibrary
+from can.ctypesutil import HRESULT as ctypes_HRESULT
+from can.exceptions import CanInitializationError, CanInterfaceNotImplementedError
+from can.typechecking import AutoDetectedConfig
 from can.util import deprecated_args_alias
 
 from . import constants, structures
@@ -73,8 +79,8 @@ def __vciFormatErrorExtended(
         Formatted string
     """
     # TODO: make sure we don't generate another exception
-    return "{} - arguments were {}".format(
-        __vciFormatError(library_instance, function, vret), args
+    return (
+        f"{__vciFormatError(library_instance, function, vret)} - arguments were {args}"
     )
 
 
@@ -119,7 +125,7 @@ def __check_status(result, function, args):
         result = ctypes.c_ulong(result).value
 
     if result == constants.VCI_E_TIMEOUT:
-        raise VCITimeout("Function {} timed out".format(function._name))
+        raise VCITimeout(f"Function {function._name} timed out")
     elif result == constants.VCI_E_RXQUEUE_EMPTY:
         raise VCIRxQueueEmptyError()
     elif result == constants.VCI_E_NO_MORE_ITEMS:
@@ -417,6 +423,8 @@ class IXXATBus(BusABC):
     }
 
     @deprecated_args_alias(
+        deprecation_start="4.0.0",
+        deprecation_end="5.0.0",
         UniqueHardwareId="unique_hardware_id",
         rxFifoSize="rx_fifo_size",
         txFifoSize="tx_fifo_size",
@@ -469,7 +477,7 @@ class IXXATBus(BusABC):
         channel = int(channel)
 
         if bitrate not in self.CHANNEL_BITRATES[0]:
-            raise ValueError("Invalid bitrate {}".format(bitrate))
+            raise ValueError(f"Invalid bitrate {bitrate}")
 
         if rx_fifo_size <= 0:
             raise ValueError("rx_fifo_size must be > 0")
@@ -487,6 +495,7 @@ class IXXATBus(BusABC):
         self._channel_capabilities = structures.CANCAPABILITIES()
         self._message = structures.CANMSG()
         self._payload = (ctypes.c_byte * 8)()
+        self._can_protocol = CanProtocol.CAN_20
 
         # Search for supplied device
         if unique_hardware_id is None:
@@ -503,13 +512,11 @@ class IXXATBus(BusABC):
                 if unique_hardware_id is None:
                     raise VCIDeviceNotFoundError(
                         "No IXXAT device(s) connected or device(s) in use by other process(es)."
-                    )
+                    ) from None
                 else:
                     raise VCIDeviceNotFoundError(
-                        "Unique HW ID {} not connected or not available.".format(
-                            unique_hardware_id
-                        )
-                    )
+                        f"Unique HW ID {unique_hardware_id} not connected or not available."
+                    ) from None
             else:
                 if (unique_hardware_id is None) or (
                     self._device_info.UniqueHardwareId.AsChar
@@ -781,20 +788,51 @@ class IXXATBus(BusABC):
         # Want to log outgoing messages?
         # log.log(self.RECV_LOGGING_LEVEL, "Sent: %s", message)
 
-    def _send_periodic_internal(self, msgs, period, duration=None):
+    def _send_periodic_internal(
+        self,
+        msgs: Union[Sequence[Message], Message],
+        period: float,
+        duration: Optional[float] = None,
+        autostart: bool = True,
+        modifier_callback: Optional[Callable[[Message], None]] = None,
+    ) -> CyclicSendTaskABC:
         """Send a message using built-in cyclic transmit list functionality."""
-        if self._scheduler is None:
-            self._scheduler = HANDLE()
-            _canlib.canSchedulerOpen(self._device_handle, self.channel, self._scheduler)
-            caps = structures.CANCAPABILITIES()
-            _canlib.canSchedulerGetCaps(self._scheduler, caps)
-            self._scheduler_resolution = caps.dwClockFreq / caps.dwCmsDivisor
-            _canlib.canSchedulerActivate(self._scheduler, constants.TRUE)
-        return CyclicSendTask(
-            self._scheduler, msgs, period, duration, self._scheduler_resolution
+        if modifier_callback is None:
+            if self._scheduler is None:
+                self._scheduler = HANDLE()
+                _canlib.canSchedulerOpen(
+                    self._device_handle, self.channel, self._scheduler
+                )
+                caps = structures.CANCAPABILITIES()
+                _canlib.canSchedulerGetCaps(self._scheduler, caps)
+                self._scheduler_resolution = caps.dwClockFreq / caps.dwCmsDivisor
+                _canlib.canSchedulerActivate(self._scheduler, constants.TRUE)
+            return CyclicSendTask(
+                self._scheduler,
+                msgs,
+                period,
+                duration,
+                self._scheduler_resolution,
+                autostart=autostart,
+            )
+
+        # fallback to thread based cyclic task
+        warnings.warn(
+            f"{self.__class__.__name__} falls back to a thread-based cyclic task, "
+            "when the `modifier_callback` argument is given.",
+            stacklevel=3,
+        )
+        return BusABC._send_periodic_internal(
+            self,
+            msgs=msgs,
+            period=period,
+            duration=duration,
+            autostart=autostart,
+            modifier_callback=modifier_callback,
         )
 
     def shutdown(self):
+        super().shutdown()
         if self._scheduler is not None:
             _canlib.canSchedulerClose(self._scheduler)
         _canlib.canChannelClose(self._channel_handle)
@@ -821,7 +859,7 @@ class IXXATBus(BusABC):
         error_byte_2 = status.dwStatus & 0xF0
         # CAN_STATUS_BUSCERR  = 0x20  # bus coupling error
         if error_byte_2 & constants.CAN_STATUS_BUSCERR:
-            raise BusState.ERROR
+            return BusState.ERROR
 
         return BusState.ACTIVE
 
@@ -832,7 +870,15 @@ class IXXATBus(BusABC):
 class CyclicSendTask(LimitedDurationCyclicSendTaskABC, RestartableCyclicTaskABC):
     """A message in the cyclic transmit list."""
 
-    def __init__(self, scheduler, msgs, period, duration, resolution):
+    def __init__(
+        self,
+        scheduler,
+        msgs,
+        period,
+        duration,
+        resolution,
+        autostart: bool = True,
+    ):
         super().__init__(msgs, period, duration)
         if len(self.messages) != 1:
             raise ValueError(
@@ -852,7 +898,8 @@ class CyclicSendTask(LimitedDurationCyclicSendTaskABC, RestartableCyclicTaskABC)
         self._msg.uMsgInfo.Bits.dlc = self.messages[0].dlc
         for i, b in enumerate(self.messages[0].data):
             self._msg.abData[i] = b
-        self.start()
+        if autostart:
+            self.start()
 
     def start(self):
         """Start transmitting message (add to list if needed)."""
@@ -887,7 +934,7 @@ def _format_can_status(status_flags: int):
             status_flags &= ~flag
 
     if status_flags:
-        states.append("unknown state 0x{:02x}".format(status_flags))
+        states.append(f"unknown state 0x{status_flags:02x}")
 
     if states:
         return "CAN status message: {}".format(", ".join(states))
@@ -912,3 +959,55 @@ def get_ixxat_hwids():
     _canlib.vciEnumDeviceClose(device_handle)
 
     return hwids
+
+
+def _detect_available_configs() -> List[AutoDetectedConfig]:
+    config_list = []  # list in wich to store the resulting bus kwargs
+
+    # used to detect HWID
+    device_handle = HANDLE()
+    device_info = structures.VCIDEVICEINFO()
+
+    # used to attempt to open channels
+    channel_handle = HANDLE()
+    device_handle2 = HANDLE()
+
+    try:
+        _canlib.vciEnumDeviceOpen(ctypes.byref(device_handle))
+        while True:
+            try:
+                _canlib.vciEnumDeviceNext(device_handle, ctypes.byref(device_info))
+            except StopIteration:
+                break
+            else:
+                hwid = device_info.UniqueHardwareId.AsChar.decode("ascii")
+                _canlib.vciDeviceOpen(
+                    ctypes.byref(device_info.VciObjectId),
+                    ctypes.byref(device_handle2),
+                )
+                for channel in range(4):
+                    try:
+                        _canlib.canChannelOpen(
+                            device_handle2,
+                            channel,
+                            constants.FALSE,
+                            ctypes.byref(channel_handle),
+                        )
+                    except Exception:
+                        # Array outside of bounds error == accessing a channel not in the hardware
+                        break
+                    else:
+                        _canlib.canChannelClose(channel_handle)
+                        config_list.append(
+                            {
+                                "interface": "ixxat",
+                                "channel": channel,
+                                "unique_hardware_id": hwid,
+                            }
+                        )
+                _canlib.vciDeviceClose(device_handle2)
+        _canlib.vciEnumDeviceClose(device_handle)
+    except AttributeError:
+        pass  # _canlib is None in the CI tests -> return a blank list
+
+    return config_list
