@@ -51,17 +51,17 @@ class VCIDEVICEINFO(ctypes.Structure):
     ]
 
     def __str__(self):
-        return "Mfg: {}, Dev: {} HW: {}.{}.{}.{} Drv: {}.{}.{}.{}".format(
-            self.Manufacturer,
-            self.Description,
-            self.HardwareBranchVersion,
-            self.HardwareMajorVersion,
-            self.HardwareMinorVersion,
-            self.HardwareBuildVersion,
-            self.DriverReleaseVersion,
-            self.DriverMajorVersion,
-            self.DriverMinorVersion,
-            self.DriverBuildVersion,
+        return (
+            f"Mfg: {self.Manufacturer}, "
+            f"Dev: {self.Description} "
+            f"HW: {self.HardwareBranchVersion}"
+            f".{self.HardwareMajorVersion}"
+            f".{self.HardwareMinorVersion}"
+            f".{self.HardwareBuildVersion} "
+            f"Drv: {self.DriverReleaseVersion}"
+            f".{self.DriverMajorVersion}"
+            f".{self.DriverMinorVersion}"
+            f".{self.DriverBuildVersion}"
         )
 
 
@@ -162,7 +162,7 @@ class CANMSG(ctypes.Structure):
     ]
 
     def __str__(self) -> str:
-        return """ID: 0x{0:04x}{1} DLC: {2:02d} DATA: {3}""".format(
+        return """ID: 0x{:04x}{} DLC: {:02d} DATA: {}""".format(
             self.dwMsgId,
             "[RTR]" if self.uMsgInfo.Bits.rtr else "",
             self.uMsgInfo.Bits.dlc,
