@@ -19,13 +19,14 @@ import sys
 from typing import Optional, Tuple, Type
 
 import can.typechecking
-from can import BusABC, Message
-
-from ..exceptions import (
+from can import (
+    BusABC,
     CanError,
     CanInitializationError,
     CanInterfaceNotImplementedError,
     CanOperationError,
+    CanProtocol,
+    Message,
 )
 
 logger = logging.getLogger(__name__)
@@ -88,7 +89,7 @@ class NicanError(CanError):
 
     def __init__(self, function, error_code: int, arguments) -> None:
         super().__init__(
-            message=f"{function} failed: {get_error_message(self.error_code)}",
+            message=f"{function} failed: {get_error_message(error_code)}",
             error_code=error_code,
         )
 
@@ -219,6 +220,7 @@ class NicanBus(BusABC):
 
         self.channel = channel
         self.channel_info = f"NI-CAN: {channel}"
+        self._can_protocol = CanProtocol.CAN_20
         channel_bytes = channel.encode("ascii")
 
         config = [(NC_ATTR_START_ON_OPEN, True), (NC_ATTR_LOG_COMM_ERRS, log_errors)]
