@@ -131,13 +131,15 @@ class SerialBus(BusABC):
         try:
             timestamp = struct.pack("<I", int(msg.timestamp * 1000))
         except struct.error:
-            raise ValueError("Timestamp is out of range")
+            raise ValueError(f"Timestamp is out of range: {msg.timestamp}") from None
 
         # Pack arbitration ID
         try:
             arbitration_id = struct.pack("<I", msg.arbitration_id)
         except struct.error:
-            raise ValueError("Arbitration ID is out of range")
+            raise ValueError(
+                f"Arbitration ID is out of range: {msg.arbitration_id}"
+            ) from None
 
         # Assemble message
         byte_msg = bytearray()
@@ -222,7 +224,7 @@ class SerialBus(BusABC):
         except io.UnsupportedOperation:
             raise NotImplementedError(
                 "fileno is not implemented using current CAN bus on this platform"
-            )
+            ) from None
         except Exception as exception:
             raise CanOperationError("Cannot fetch fileno") from exception
 
