@@ -3,15 +3,16 @@ Defines common socketcan functions.
 """
 
 import errno
+import json
 import logging
 import os
-import re
 import struct
 import subprocess
-from typing import cast, Iterable, Optional
+import sys
+from typing import List, Optional, cast
 
-from can.interfaces.socketcan.constants import CAN_EFF_FLAG
 from can import typechecking
+from can.interfaces.socketcan.constants import CAN_EFF_FLAG
 
 log = logging.getLogger(__name__)
 
@@ -21,7 +22,7 @@ def pack_filters(can_filters: Optional[typechecking.CanFilters] = None) -> bytes
         # Pass all messages
         can_filters = [{"can_id": 0, "can_mask": 0}]
 
-    can_filter_fmt = "={}I".format(2 * len(can_filters))
+    can_filter_fmt = f"={2 * len(can_filters)}I"
     filter_data = []
     for can_filter in can_filters:
         can_id = can_filter["can_id"]
@@ -38,34 +39,38 @@ def pack_filters(can_filters: Optional[typechecking.CanFilters] = None) -> bytes
     return struct.pack(can_filter_fmt, *filter_data)
 
 
-_PATTERN_CAN_INTERFACE = re.compile(r"(sl|v|vx)?can\d+")
+def find_available_interfaces() -> List[str]:
+    """Returns the names of all open can/vcan interfaces
 
-
-def find_available_interfaces() -> Iterable[str]:
-    """Returns the names of all open can/vcan interfaces using
-    the ``ip link list`` command. If the lookup fails, an error
+    The function calls the ``ip link list`` command. If the lookup fails, an error
     is logged to the console and an empty list is returned.
+
+    :return: The list of available and active CAN interfaces or an empty list of the command failed
     """
-
-    try:
-        # adding "type vcan" would exclude physical can devices
-        command = ["ip", "-o", "link", "list", "up"]
-        output = subprocess.check_output(command, universal_newlines=True)
-
-    except Exception as e:  # subprocess.CalledProcessError is too specific
-        log.error("failed to fetch opened can devices: %s", e)
+    if sys.platform != "linux":
         return []
 
-    else:
-        # log.debug("find_available_interfaces(): output=\n%s", output)
-        # output contains some lines like "1: vcan42: <NOARP,UP,LOWER_UP> ..."
-        # extract the "vcan42" of each line
-        interfaces = [line.split(": ", 3)[1] for line in output.splitlines()]
-        log.debug(
-            "find_available_interfaces(): detected these interfaces (before filtering): %s",
-            interfaces,
-        )
-        return filter(_PATTERN_CAN_INTERFACE.match, interfaces)
+    try:
+        command = ["ip", "-json", "link", "list", "up"]
+        output_str = subprocess.check_output(command, text=True)
+    except Exception:  # pylint: disable=broad-except
+        # subprocess.CalledProcessError is too specific
+        log.exception("failed to fetch opened can devices from ip link")
+        return []
+
+    try:
+        output_json = json.loads(output_str)
+    except json.JSONDecodeError:
+        log.exception("Failed to parse ip link JSON output: %s", output_str)
+        return []
+
+    log.debug(
+        "find_available_interfaces(): detected these interfaces (before filtering): %s",
+        output_json,
+    )
+
+    interfaces = [i["ifname"] for i in output_json if i.get("link_type") == "can"]
+    return interfaces
 
 
 def error_code_to_str(code: Optional[int]) -> str:
