@@ -5,11 +5,12 @@ It is is compatible with "candump -L" from the canutils program
 """
 
 import logging
-from typing import Generator, TextIO, Union, Any
+from typing import Any, Generator, TextIO, Union
 
 from can.message import Message
-from .generic import FileIOMessageWriter, MessageReader
+
 from ..typechecking import StringPathLike
+from .generic import TextIOMessageReader, TextIOMessageWriter
 
 log = logging.getLogger("can.io.canutils")
 
@@ -22,7 +23,7 @@ CANFD_BRS = 0x01
 CANFD_ESI = 0x02
 
 
-class CanutilsLogReader(MessageReader):
+class CanutilsLogReader(TextIOMessageReader):
     """
     Iterator over CAN messages from a .log Logging File (candump -L).
 
@@ -37,7 +38,6 @@ class CanutilsLogReader(MessageReader):
     def __init__(
         self,
         file: Union[StringPathLike, TextIO],
-        *args: Any,
         **kwargs: Any,
     ) -> None:
         """
@@ -49,7 +49,6 @@ class CanutilsLogReader(MessageReader):
 
     def __iter__(self) -> Generator[Message, None, None]:
         for line in self.file:
-
             # skip empty lines
             temp = line.strip()
             if not temp:
@@ -123,7 +122,7 @@ class CanutilsLogReader(MessageReader):
         self.stop()
 
 
-class CanutilsLogWriter(FileIOMessageWriter):
+class CanutilsLogWriter(TextIOMessageWriter):
     """Logs CAN data to an ASCII log file (.log).
     This class is is compatible with "candump -L".
 
@@ -137,7 +136,6 @@ class CanutilsLogWriter(FileIOMessageWriter):
         file: Union[StringPathLike, TextIO],
         channel: str = "vcan0",
         append: bool = False,
-        *args: Any,
         **kwargs: Any,
     ):
         """
@@ -170,14 +168,14 @@ class CanutilsLogWriter(FileIOMessageWriter):
         if isinstance(channel, int) or isinstance(channel, str) and channel.isdigit():
             channel = f"can{channel}"
 
-        framestr = "(%f) %s" % (timestamp, channel)
+        framestr = f"({timestamp:f}) {channel}"
 
         if msg.is_error_frame:
-            framestr += " %08X#" % (CAN_ERR_FLAG | CAN_ERR_BUSERROR)
+            framestr += f" {CAN_ERR_FLAG | CAN_ERR_BUSERROR:08X}#"
         elif msg.is_extended_id:
-            framestr += " %08X#" % (msg.arbitration_id)
+            framestr += f" {msg.arbitration_id:08X}#"
         else:
-            framestr += " %03X#" % (msg.arbitration_id)
+            framestr += f" {msg.arbitration_id:03X}#"
 
         if msg.is_error_frame:
             eol = "\n"
@@ -193,7 +191,7 @@ class CanutilsLogWriter(FileIOMessageWriter):
                     fd_flags |= CANFD_BRS
                 if msg.error_state_indicator:
                     fd_flags |= CANFD_ESI
-                framestr += "#%X" % fd_flags
+                framestr += f"#{fd_flags:X}"
             framestr += f"{msg.data.hex().upper()}{eol}"
 
         self.file.write(framestr)
