@@ -1,19 +1,27 @@
 """Contains generic base classes for file IO."""
 
+import gzip
+import locale
 from abc import ABCMeta
-from typing import (
-    Optional,
-    cast,
-    Iterable,
-    Type,
-    ContextManager,
-    Any,
-)
-from typing_extensions import Literal
 from types import TracebackType
+from typing import (
+    Any,
+    BinaryIO,
+    ContextManager,
+    Iterable,
+    Literal,
+    Optional,
+    TextIO,
+    Type,
+    Union,
+    cast,
+)
 
-import can
-import can.typechecking
+from typing_extensions import Self
+
+from .. import typechecking
+from ..listener import Listener
+from ..message import Message
 
 
 class BaseIOHandler(ContextManager, metaclass=ABCMeta):
@@ -26,14 +34,13 @@ class BaseIOHandler(ContextManager, metaclass=ABCMeta):
         was opened
     """
 
-    file: Optional[can.typechecking.FileLike]
+    file: Optional[typechecking.FileLike]
 
     def __init__(
         self,
-        file: Optional[can.typechecking.AcceptedIOType],
+        file: Optional[typechecking.AcceptedIOType],
         mode: str = "rt",
-        *args: Any,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
         """
         :param file: a path-like object to open a file, a file-like object
@@ -43,19 +50,24 @@ class BaseIOHandler(ContextManager, metaclass=ABCMeta):
         """
         if file is None or (hasattr(file, "read") and hasattr(file, "write")):
             # file is None or some file-like object
-            self.file = cast(Optional[can.typechecking.FileLike], file)
+            self.file = cast(Optional[typechecking.FileLike], file)
         else:
+            encoding: Optional[str] = (
+                None
+                if "b" in mode
+                else kwargs.get("encoding", locale.getpreferredencoding(False))
+            )
             # pylint: disable=consider-using-with
             # file is some path-like object
             self.file = cast(
-                can.typechecking.FileLike,
-                open(cast(can.typechecking.StringPathLike, file), mode),
+                typechecking.FileLike,
+                open(cast(typechecking.StringPathLike, file), mode, encoding=encoding),
             )
 
         # for multiple inheritance
         super().__init__()
 
-    def __enter__(self) -> "BaseIOHandler":
+    def __enter__(self) -> Self:
         return self
 
     def __exit__(
@@ -74,37 +86,46 @@ class BaseIOHandler(ContextManager, metaclass=ABCMeta):
             self.file.close()
 
 
-# pylint: disable=abstract-method,too-few-public-methods
-class MessageWriter(BaseIOHandler, can.Listener, metaclass=ABCMeta):
+class MessageWriter(BaseIOHandler, Listener, metaclass=ABCMeta):
     """The base class for all writers."""
 
-    file: Optional[can.typechecking.FileLike]
+    file: Optional[typechecking.FileLike]
 
 
-# pylint: disable=abstract-method,too-few-public-methods
 class FileIOMessageWriter(MessageWriter, metaclass=ABCMeta):
     """A specialized base class for all writers with file descriptors."""
 
-    file: can.typechecking.FileLike
+    file: typechecking.FileLike
 
     def __init__(
-        self,
-        file: can.typechecking.AcceptedIOType,
-        mode: str = "wt",
-        *args: Any,
-        **kwargs: Any
+        self, file: typechecking.AcceptedIOType, mode: str = "wt", **kwargs: Any
     ) -> None:
         # Not possible with the type signature, but be verbose for user-friendliness
         if file is None:
             raise ValueError("The given file cannot be None")
 
-        super().__init__(file, mode)
+        super().__init__(file, mode, **kwargs)
 
     def file_size(self) -> int:
         """Return an estimate of the current file size in bytes."""
         return self.file.tell()
 
 
-# pylint: disable=too-few-public-methods
-class MessageReader(BaseIOHandler, Iterable[can.Message], metaclass=ABCMeta):
+class TextIOMessageWriter(FileIOMessageWriter, metaclass=ABCMeta):
+    file: TextIO
+
+
+class BinaryIOMessageWriter(FileIOMessageWriter, metaclass=ABCMeta):
+    file: Union[BinaryIO, gzip.GzipFile]
+
+
+class MessageReader(BaseIOHandler, Iterable[Message], metaclass=ABCMeta):
     """The base class for all readers."""
+
+
+class TextIOMessageReader(MessageReader, metaclass=ABCMeta):
+    file: TextIO
+
+
+class BinaryIOMessageReader(MessageReader, metaclass=ABCMeta):
+    file: Union[BinaryIO, gzip.GzipFile]
