@@ -1,6 +1,8 @@
 """
 Utilities and configuration file parsing.
 """
+
+import contextlib
 import copy
 import functools
 import json
@@ -24,6 +26,8 @@ from typing import (
     cast,
 )
 
+from typing_extensions import ParamSpec
+
 import can
 
 from . import typechecking
@@ -41,7 +45,7 @@ REQUIRED_KEYS = ["interface", "channel"]
 
 CONFIG_FILES = ["~/can.conf"]
 
-if platform.system() == "Linux":
+if platform.system() in ("Linux", "Darwin"):
     CONFIG_FILES.extend(["/etc/can.conf", "~/.can", "~/.canrc"])
 elif platform.system() == "Windows" or platform.python_implementation() == "IronPython":
     CONFIG_FILES.extend(["can.ini", os.path.join(os.getenv("APPDATA", ""), "can.ini")])
@@ -66,7 +70,7 @@ def load_file_config(
     config = ConfigParser()
 
     # make sure to not transform the entries such that capitalization is preserved
-    config.optionxform = lambda entry: entry  # type: ignore
+    config.optionxform = lambda optionstr: optionstr  # type: ignore[method-assign]
 
     if path is None:
         config.read([os.path.expanduser(path) for path in CONFIG_FILES])
@@ -188,9 +192,8 @@ def load_config(
     )
 
     # Slightly complex here to only search for the file config if required
-    for cfg in config_sources:
-        if callable(cfg):
-            cfg = cfg(context)
+    for _cfg in config_sources:
+        cfg = _cfg(context) if callable(_cfg) else _cfg
         # remove legacy operator (and copy to interface if not already present)
         if "bustype" in cfg:
             if "interface" not in cfg or not cfg["interface"]:
@@ -241,24 +244,9 @@ def _create_bus_config(config: Dict[str, Any]) -> typechecking.BusConfig:
         if not 0 < port < 65535:
             raise ValueError("Port config must be inside 0-65535 range!")
 
-    if config.get("timing", None) is None:
-        try:
-            if set(typechecking.BitTimingFdDict.__annotations__).issubset(config):
-                config["timing"] = can.BitTimingFd(
-                    **{
-                        key: int(config[key])
-                        for key in typechecking.BitTimingFdDict.__annotations__
-                    }
-                )
-            elif set(typechecking.BitTimingDict.__annotations__).issubset(config):
-                config["timing"] = can.BitTiming(
-                    **{
-                        key: int(config[key])
-                        for key in typechecking.BitTimingDict.__annotations__
-                    }
-                )
-        except (ValueError, TypeError):
-            pass
+    if "timing" not in config:
+        if timing := _dict2timing(config):
+            config["timing"] = timing
 
     if "fd" in config:
         config["fd"] = config["fd"] not in (0, False)
@@ -266,6 +254,31 @@ def _create_bus_config(config: Dict[str, Any]) -> typechecking.BusConfig:
     return cast(typechecking.BusConfig, config)
 
 
+def _dict2timing(data: Dict[str, Any]) -> Union[BitTiming, BitTimingFd, None]:
+    """Try to instantiate a :class:`~can.BitTiming` or :class:`~can.BitTimingFd` from
+    a dictionary. Return `None` if not possible."""
+
+    with contextlib.suppress(ValueError, TypeError):
+        if set(typechecking.BitTimingFdDict.__annotations__).issubset(data):
+            return BitTimingFd(
+                **{
+                    key: int(data[key])
+                    for key in typechecking.BitTimingFdDict.__annotations__
+                },
+                strict=False,
+            )
+        elif set(typechecking.BitTimingDict.__annotations__).issubset(data):
+            return BitTiming(
+                **{
+                    key: int(data[key])
+                    for key in typechecking.BitTimingDict.__annotations__
+                },
+                strict=False,
+            )
+
+    return None
+
+
 def set_logging_level(level_name: str) -> None:
     """Set the logging level for the `"can"` logger.
 
@@ -325,9 +338,15 @@ def channel2int(channel: Optional[typechecking.Channel]) -> Optional[int]:
     return None
 
 
-def deprecated_args_alias(  # type: ignore
-    deprecation_start: str, deprecation_end: Optional[str] = None, **aliases
-):
+P1 = ParamSpec("P1")
+T1 = TypeVar("T1")
+
+
+def deprecated_args_alias(
+    deprecation_start: str,
+    deprecation_end: Optional[str] = None,
+    **aliases: Optional[str],
+) -> Callable[[Callable[P1, T1]], Callable[P1, T1]]:
     """Allows to rename/deprecate a function kwarg(s) and optionally
     have the deprecated kwarg(s) set as alias(es)
 
@@ -356,9 +375,9 @@ def deprecated_args_alias(  # type: ignore
 
     """
 
-    def deco(f):
+    def deco(f: Callable[P1, T1]) -> Callable[P1, T1]:
         @functools.wraps(f)
-        def wrapper(*args, **kwargs):
+        def wrapper(*args: P1.args, **kwargs: P1.kwargs) -> T1:
             _rename_kwargs(
                 func_name=f.__name__,
                 start=deprecation_start,
@@ -373,10 +392,42 @@ def deprecated_args_alias(  # type: ignore
     return deco
 
 
-T = TypeVar("T", BitTiming, BitTimingFd)
+def _rename_kwargs(
+    func_name: str,
+    start: str,
+    end: Optional[str],
+    kwargs: P1.kwargs,
+    aliases: Dict[str, Optional[str]],
+) -> None:
+    """Helper function for `deprecated_args_alias`"""
+    for alias, new in aliases.items():
+        if alias in kwargs:
+            deprecation_notice = (
+                f"The '{alias}' argument is deprecated since python-can v{start}"
+            )
+            if end:
+                deprecation_notice += (
+                    f", and scheduled for removal in python-can v{end}"
+                )
+            deprecation_notice += "."
+
+            value = kwargs.pop(alias)
+            if new is not None:
+                deprecation_notice += f" Use '{new}' instead."
+
+                if new in kwargs:
+                    raise TypeError(
+                        f"{func_name} received both '{alias}' (deprecated) and '{new}'."
+                    )
+                kwargs[new] = value
+
+            warnings.warn(deprecation_notice, DeprecationWarning, stacklevel=3)
 
 
-def check_or_adjust_timing_clock(timing: T, valid_clocks: Iterable[int]) -> T:
+T2 = TypeVar("T2", BitTiming, BitTimingFd)
+
+
+def check_or_adjust_timing_clock(timing: T2, valid_clocks: Iterable[int]) -> T2:
     """Adjusts the given timing instance to have an *f_clock* value that is within the
     allowed values specified by *valid_clocks*. If the *f_clock* value of timing is
     already within *valid_clocks*, then *timing* is returned unchanged.
@@ -403,7 +454,8 @@ def check_or_adjust_timing_clock(timing: T, valid_clocks: Iterable[int]) -> T:
             adjusted_timing = timing.recreate_with_f_clock(clock)
             warnings.warn(
                 f"Adjusted f_clock in {timing.__class__.__name__} from "
-                f"{timing.f_clock} to {adjusted_timing.f_clock}"
+                f"{timing.f_clock} to {adjusted_timing.f_clock}",
+                stacklevel=2,
             )
             return adjusted_timing
         except ValueError:
@@ -416,38 +468,6 @@ def check_or_adjust_timing_clock(timing: T, valid_clocks: Iterable[int]) -> T:
     ) from None
 
 
-def _rename_kwargs(
-    func_name: str,
-    start: str,
-    end: Optional[str],
-    kwargs: Dict[str, str],
-    aliases: Dict[str, str],
-) -> None:
-    """Helper function for `deprecated_args_alias`"""
-    for alias, new in aliases.items():
-        if alias in kwargs:
-            deprecation_notice = (
-                f"The '{alias}' argument is deprecated since python-can v{start}"
-            )
-            if end:
-                deprecation_notice += (
-                    f", and scheduled for removal in python-can v{end}"
-                )
-            deprecation_notice += "."
-
-            value = kwargs.pop(alias)
-            if new is not None:
-                deprecation_notice += f" Use '{new}' instead."
-
-                if new in kwargs:
-                    raise TypeError(
-                        f"{func_name} received both '{alias}' (deprecated) and '{new}'."
-                    )
-                kwargs[new] = value
-
-            warnings.warn(deprecation_notice, DeprecationWarning)
-
-
 def time_perfcounter_correlation() -> Tuple[float, float]:
     """Get the `perf_counter` value nearest to when time.time() is updated
 
@@ -497,11 +517,3 @@ def cast_from_string(string_val: str) -> Union[str, int, float, bool]:
 
     # value is string
     return string_val
-
-
-if __name__ == "__main__":
-    print("Searching for configuration named:")
-    print("\n".join(CONFIG_FILES))
-    print()
-    print("Settings:")
-    print(load_config())
