@@ -21,6 +21,7 @@ class KvaserTest(unittest.TestCase):
         canlib.canIoCtl = Mock(return_value=0)
         canlib.canIoCtlInit = Mock(return_value=0)
         canlib.kvReadTimer = Mock()
+        canlib.canSetBusParamsC200 = Mock()
         canlib.canSetBusParams = Mock()
         canlib.canSetBusParamsFd = Mock()
         canlib.canBusOn = Mock()
@@ -46,6 +47,7 @@ class KvaserTest(unittest.TestCase):
 
     def test_bus_creation(self):
         self.assertIsInstance(self.bus, canlib.KvaserBus)
+        self.assertEqual(self.bus.protocol, can.CanProtocol.CAN_20)
         self.assertTrue(canlib.canOpenChannel.called)
         self.assertTrue(canlib.canBusOn.called)
 
@@ -161,15 +163,28 @@ class KvaserTest(unittest.TestCase):
     def test_available_configs(self):
         configs = canlib.KvaserBus._detect_available_configs()
         expected = [
-            {"interface": "kvaser", "channel": 0},
-            {"interface": "kvaser", "channel": 1},
+            {
+                "interface": "kvaser",
+                "channel": 0,
+                "dongle_channel": 1,
+                "device_name": "",
+                "serial": 0,
+            },
+            {
+                "interface": "kvaser",
+                "channel": 1,
+                "dongle_channel": 1,
+                "device_name": "",
+                "serial": 0,
+            },
         ]
         self.assertListEqual(configs, expected)
 
     def test_canfd_default_data_bitrate(self):
         canlib.canSetBusParams.reset_mock()
         canlib.canSetBusParamsFd.reset_mock()
-        can.Bus(channel=0, interface="kvaser", fd=True)
+        bus = can.Bus(channel=0, interface="kvaser", fd=True)
+        self.assertEqual(bus.protocol, can.CanProtocol.CAN_FD)
         canlib.canSetBusParams.assert_called_once_with(
             0, constants.canFD_BITRATE_500K_80P, 0, 0, 0, 0, 0
         )
@@ -177,11 +192,70 @@ class KvaserTest(unittest.TestCase):
             0, constants.canFD_BITRATE_500K_80P, 0, 0, 0
         )
 
+    def test_can_timing(self):
+        canlib.canSetBusParams.reset_mock()
+        canlib.canSetBusParamsFd.reset_mock()
+        timing = can.BitTiming.from_bitrate_and_segments(
+            f_clock=16_000_000,
+            bitrate=125_000,
+            tseg1=13,
+            tseg2=2,
+            sjw=1,
+        )
+        can.Bus(channel=0, interface="kvaser", timing=timing)
+        canlib.canSetBusParamsC200.assert_called_once_with(0, timing.btr0, timing.btr1)
+
+    def test_canfd_timing(self):
+        canlib.canSetBusParams.reset_mock()
+        canlib.canSetBusParamsFd.reset_mock()
+        canlib.canOpenChannel.reset_mock()
+        timing = can.BitTimingFd.from_bitrate_and_segments(
+            f_clock=80_000_000,
+            nom_bitrate=500_000,
+            nom_tseg1=68,
+            nom_tseg2=11,
+            nom_sjw=10,
+            data_bitrate=2_000_000,
+            data_tseg1=10,
+            data_tseg2=9,
+            data_sjw=8,
+        )
+        can.Bus(channel=0, interface="kvaser", timing=timing)
+        canlib.canSetBusParams.assert_called_once_with(0, 500_000, 68, 11, 10, 1, 0)
+        canlib.canSetBusParamsFd.assert_called_once_with(0, 2_000_000, 10, 9, 8)
+        canlib.canOpenChannel.assert_called_with(
+            0, constants.canOPEN_CAN_FD | constants.canOPEN_ACCEPT_VIRTUAL
+        )
+
+    def test_canfd_non_iso(self):
+        canlib.canSetBusParams.reset_mock()
+        canlib.canSetBusParamsFd.reset_mock()
+        canlib.canOpenChannel.reset_mock()
+        timing = can.BitTimingFd.from_bitrate_and_segments(
+            f_clock=80_000_000,
+            nom_bitrate=500_000,
+            nom_tseg1=68,
+            nom_tseg2=11,
+            nom_sjw=10,
+            data_bitrate=2_000_000,
+            data_tseg1=10,
+            data_tseg2=9,
+            data_sjw=8,
+        )
+        bus = can.Bus(channel=0, interface="kvaser", timing=timing, fd_non_iso=True)
+        self.assertEqual(bus.protocol, can.CanProtocol.CAN_FD_NON_ISO)
+        canlib.canSetBusParams.assert_called_once_with(0, 500_000, 68, 11, 10, 1, 0)
+        canlib.canSetBusParamsFd.assert_called_once_with(0, 2_000_000, 10, 9, 8)
+        canlib.canOpenChannel.assert_called_with(
+            0, constants.canOPEN_CAN_FD_NONISO | constants.canOPEN_ACCEPT_VIRTUAL
+        )
+
     def test_canfd_nondefault_data_bitrate(self):
         canlib.canSetBusParams.reset_mock()
         canlib.canSetBusParamsFd.reset_mock()
         data_bitrate = 2000000
-        can.Bus(channel=0, interface="kvaser", fd=True, data_bitrate=data_bitrate)
+        bus = can.Bus(channel=0, interface="kvaser", fd=True, data_bitrate=data_bitrate)
+        self.assertEqual(bus.protocol, can.CanProtocol.CAN_FD)
         bitrate_constant = canlib.BITRATE_FD[data_bitrate]
         canlib.canSetBusParams.assert_called_once_with(
             0, constants.canFD_BITRATE_500K_80P, 0, 0, 0, 0, 0
