@@ -48,6 +48,7 @@ def mock_xldriver() -> None:
     xldriver_mock.xlCanSetChannelAcceptance = Mock(return_value=0)
     xldriver_mock.xlCanSetChannelBitrate = Mock(return_value=0)
     xldriver_mock.xlSetNotification = Mock(side_effect=xlSetNotification)
+    xldriver_mock.xlCanSetChannelOutput = Mock(return_value=0)
 
     # bus deactivation functions
     xldriver_mock.xlDeactivateChannel = Mock(return_value=0)
@@ -78,6 +79,44 @@ def mock_xldriver() -> None:
     canlib.HAS_EVENTS = real_has_events
 
 
+def test_listen_only_mocked(mock_xldriver) -> None:
+    bus = can.Bus(channel=0, interface="vector", listen_only=True, _testing=True)
+    assert isinstance(bus, canlib.VectorBus)
+    assert bus.protocol == can.CanProtocol.CAN_20
+
+    can.interfaces.vector.canlib.xldriver.xlCanSetChannelOutput.assert_called()
+    xlCanSetChannelOutput_args = (
+        can.interfaces.vector.canlib.xldriver.xlCanSetChannelOutput.call_args[0]
+    )
+    assert xlCanSetChannelOutput_args[2] == xldefine.XL_OutputMode.XL_OUTPUT_MODE_SILENT
+
+
+@pytest.mark.skipif(not XLDRIVER_FOUND, reason="Vector XL API is unavailable")
+def test_listen_only() -> None:
+    bus = can.Bus(
+        channel=0,
+        serial=_find_virtual_can_serial(),
+        interface="vector",
+        receive_own_messages=True,
+        listen_only=True,
+    )
+    assert isinstance(bus, canlib.VectorBus)
+    assert bus.protocol == can.CanProtocol.CAN_20
+
+    msg = can.Message(
+        arbitration_id=0xC0FFEF, data=[1, 2, 3, 4, 5, 6, 7, 8], is_extended_id=True
+    )
+
+    bus.send(msg)
+
+    received_msg = bus.recv()
+
+    assert received_msg.arbitration_id == msg.arbitration_id
+    assert received_msg.data == msg.data
+
+    bus.shutdown()
+
+
 def test_bus_creation_mocked(mock_xldriver) -> None:
     bus = can.Bus(channel=0, interface="vector", _testing=True)
     assert isinstance(bus, canlib.VectorBus)
